/*
 * @Company: hugeInfo
 * @Author: ldh
 * @Date: 2022-08-13 14:28:11
 * @LastEditTime: 2022-09-24 14:50:30
 * @LastEditors: ldh
 * @Version: 1.0.0
 * @Description: 房间详情页 - 单位信息
 */
import React from 'react';
import { Space } from 'dingtalk-design-mobile';
import { personCard_icon } from '../../assets/icon';
import { avatar1, avatar2 } from '../../assets/img';
import { useHistory } from 'react-router-dom';
import Descriptions from '../Descriptions';
import ImgShow from '../ImgShow';

const UnitMsg = ({ onlyCheck, houseId, data }) => {
	const history = useHistory();
	return (
		<div className="roomDetail-roomMsg-main roomDetail-unitMsg-main">
			<div className="roomDetail-roomMsg-card roomDetail-unitMsg-card">
				<Descriptions
					title="基本信息"
					topRightActionVisible={!onlyCheck}
					data={[
						{ label: '单位名称', value: data.unitname },
						{ label: '统一信用代码', value: data.unitcode },
						{ label: '单位性质', value: data.unittypeDesc },
						{ label: '单位类型', value: data.classifyName },
					]}
					columns={1}
					onTopRightAction={() => history.push(`/hztGrid/room/FormUnit?id=${data.id}&houseId=${houseId}`)}
				/>
			</div>
			<div className="roomDetail-roomMsg-card roomDetail-unitMsg-card">
				<div className="roomDetail-roomMsg-card-title">责任人信息</div>
				<div className="roomDetail-msgCard roomDetail-msgCard-blue">
					{!data.pCorporationName ? (
						<>
							<div className="roomDetail-msgCard-avatar">
								<img src={personCard_icon} alt="" />
							</div>
							<div className="roomDetail-msgCard-desc">尚未登记法人信息</div>
						</>
					) : (
						<>
							<div className="roomDetail-msgCard-avatar">
								<img src={avatar1} alt="" />
							</div>
							<div className="roomDetail-msgCard-content">
								<Space align="center">
									<span>{data.pCorporationName}</span>
									<span>{data.pCorporationPhone}</span>
									<span className="public-tag2 public-tag2-blue">法人</span>
								</Space>
								<div className="roomDetail-msgCard-content-desc">
									<span>{data.pCorporationIdTypeName}</span>
									<span className="public-rightBorder">{data.pCorporationIdCard}</span>
								</div>
							</div>
						</>
					)}
				</div>
				<div className="roomDetail-msgCard roomDetail-msgCard-blue">
					{!data.pPrincipalName ? (
						<>
							<div className="roomDetail-msgCard-avatar">
								<img src={personCard_icon} alt="" />
							</div>
							<div className="roomDetail-msgCard-desc">尚未登记责任人信息</div>
						</>
					) : (
						<>
							<div className="roomDetail-msgCard-avatar">
								<img src={avatar2} alt="" />
							</div>
							<div className="roomDetail-msgCard-content">
								<Space align="center">
									<span>{data.pPrincipalName}</span>
									<span>{data.pPrincipalPhone}</span>
									<span className="public-tag2 public-tag2-blue">负责人</span>
								</Space>
								<div className="roomDetail-msgCard-content-desc">
									<span>{data.pPrincipalIdTypeName}</span>
									<span className="public-rightBorder">{data.pPrincipalIdCard}</span>
								</div>
							</div>
						</>
					)}
				</div>
			</div>
			<div className="roomDetail-roomMsg-card roomDetail-unitMsg-card">
				<div className="roomDetail-roomMsg-card-title">单位附件</div>
				<div className="roomDetail-roomMsg-card-file">
					{data.fileList?.map((x, t) => (
						<div className="roomDetail-roomMsg-card-file-item" key={t}>
							<ImgShow img={x.showUrl} allImg={data.fileList} title={x.name} />
						</div>
					))}
					{(data.fileList || []).length === 0 && (
						<div className="roomDetail-roomMsg-card-file-item">
							<ImgShow />
						</div>
					)}
				</div>
			</div>
		</div>
	);
};

export default UnitMsg;
